#
# spec file for package step-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

%define configdir /etc/step
%define certsdir  /etc/step/certs
%define services  cert-renewer.target ssh-cert-renewer.timer ssh-cert-renewer@.timer cert-renewer@.timer ssh-cert-renewer.service ssh-cert-renewer@.service cert-renewer@.service
%define executable_name step
%define pkg_name cli

Name:           step-cli
Version:        0.27.4
Release:        1.1
Summary:        Zero trust swiss army knife for working with X509, OAuth, JWT, OATH OTP, etc
License:        Apache-2.0
Group:          Productivity/Networking/Security
URL:            https://github.com/smallstep/cli
Source:         cli-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        series
Patch:          more-units.patch
Patch1:         add-missing-targets.patch
BuildRequires:  go >= 1.22
Conflicts:      step

%description
step is an easy-to-use CLI tool for building, operating, and automating Public
Key Infrastructure (PKI) systems and workflows. It's the client counterpart to
the step-ca online Certificate Authority (CA). You can use it for many common
crypto and X.509 operations—either independently, or with an online CA.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1 -n %{pkg_name}-%{version}

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X main.Version=%{version} \
   -X main.BuildDate=$BUILD_DATE" \
   -o bin/%{executable_name} github.com/smallstep/cli/cmd/step

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{executable_name}

for unit in %{services} ; do
install -D -m 0644 systemd/${unit} %{buildroot}%{_unitdir}/${unit}
done

install -D -d -m 0711 %{buildroot}%{configdir}/{certs,config}

%check
bin/%{executable_name} --version | grep %{version}

%pre
%service_add_pre %{services}

%post
%service_add_post %{services}

%preun
%service_del_preun %{services}

%postun
%service_del_postun %{services}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}
%{_unitdir}/ssh-cert-renewer.service
%{_unitdir}/ssh-cert-renewer.timer
%{_unitdir}/ssh-cert-renewer@.service
%{_unitdir}/ssh-cert-renewer@.timer
%{_unitdir}/cert-renewer@.service
%{_unitdir}/cert-renewer@.timer
%{_unitdir}/cert-renewer.target
%config(noreplace) %attr(-,root,root)    %{configdir}
%config(noreplace) %attr(640,root,root) %ghost    %{configdir}/config/defaults.json

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{executable_name}

%changelog
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.27.4:
  * Bump smallstep/certificates to 0.27.4 (#1276)
  * Bumping CHANGELOG to 0.27.4 (#1275)
  * Update changelog for 0.27.3 (#1272)
  * Allow input from stdin for 'certificate fingerprint' command
    (#1270)
  * Bump go.mozilla.org/pkcs7
  * Bump golang.org/x/crypto from 0.26.0 to 0.27.0
  * Bump go.step.sm/crypto from 0.51.1 to 0.51.2
  * Bump software.sslmate.com/src/go-pkcs12 from 0.4.0 to 0.5.0
  * Parse crlEntryExtensions in CRLs
  * Bump github.com/google/go-tpm from 0.9.0 to 0.9.1
  * Fix linter issues
  * Run `go mod tidy`
  * Bump github.com/slackhq/nebula from 1.8.2 to 1.9.3
  * Fix Release URLs with new file name formats. (#1256)
  * Guard legacy Windows vt100 setup syscall on more recent builds
    of Windows
  * Switch to goreleaser.yml@main.
  * Set NFPM id and remove GORELEASER_PHASE.
  * Adjust template.
  * Unquote the things.
  * Add quotes.
  * Switch to is-prerelease.
  * Move package import logic into package-repo-import.sh and use
    IS_PRERELEASE.
  * Switch back to goreleaser.yml@main.
  * Bump golang.org/x/crypto from 0.25.0 to 0.26.0
  * Bump golang.org/x/sys from 0.23.0 to 0.24.0
  * Fix Debian ARMv6 and ARMv7 duplicated package names.
  * Ignore goreleaser dist/ directory.
  * Set enable-packages-upload: true.
  * Add packages: write.
  * Use goreleaser.yml@jdoss/Package_Repos for testing.
  * Fix conditional for uploading packages
  * Add missing variables.
  * Update scripts/package-repo-import.sh
  * Update scripts/package-repo-import.sh
  * Add yaml-language-server modline to set the YAML schema to
    Goreleaser Pro.
  * Add support in for signing and publishing RPM and Deb packages
    to GCP Artifact Registry.
  * Bump golang.org/x/sys from 0.22.0 to 0.23.0
  * Fix `x5rt#S256` for SSH public keys and tests
  * Bump go.step.sm/crypto from 0.50.0 to 0.51.1
  * Fix linter warning
  * Apply suggestions from code review
  * Remove SSH cfn support and use x5rt#S256 property
  * [ci] remove duplicate s3 builds in favor of name_templates in
    s3 upload step (#1244)
  * Fix builds
  * Fix debug
  * Default id back in makefile
  * Explicitly name the default build 'step'
  * Goreleaser s3 upload not working (#1243)
  * Remove the extra "default" build
  * Remove redundant /
  * Bump softprops/action-gh-release from 2.0.6 to 2.0.8
  * Cleanups and small fixes
  * Bump github.com/smallstep/certificates from 0.27.1 to 0.27.2
  * Rename INSTALL_PREFIX to DESTDIR and fix BINNAME
  * One more fix
  * Re-add BINNAME and describe available vars
  * Build using go by default. Add goreleaser goal and an intro at
    the top
  * Cleanups
  * Use GoReleaser Pro for Makefile builds
  * Install goreleaser-pro in make bootstrap
  * Allow to add confirmation claims to tokens
  * Generate fingerprints for CSRs
* Thu Jul 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.27.2:
  * Update changelog for 0.27.2 (#1240)
  * Upload freebsd binaries to s3 (#1239)
  * Add console flag to ssh commands
  * Bump actions/setup-go from 5.0.1 to 5.0.2
  * Bump github.com/smallstep/certificates from 0.27.0 to 0.27.1
  * [actions] use ref_name as name for release (#1235)
* Sat Jul 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.27.1:
  * neq -> ne (#1234)
* Sat Jul 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.27.0:
  * Update certificate to 0.27.0 (#1233)
  * See notes ... (#1232)
  * Update go.step.sm/crypto
  * Move S3 binary build-deploy to GoReleaser
  * Bump google.golang.org/grpc from 1.64.0 to 1.64.1
  * Makefile: install to /usr/local/bin, not /usr/bin (#1214)
  * Bump golang.org/x/term from 0.21.0 to 0.22.0
  * Bump go.step.sm/crypto from 0.47.1 to 0.48.1
  * Makefile: fix usage of install command line flags on macOS
    (#1212)
  * Fix fish completion
  * Fix error message on step certificate inspect
  * Restore check for the option `bundle` in the URL certificate
    inspection (#1215)
  * Update goreleaser YML version (#1220)
  * Bump go.step.sm/linkedca from 0.22.0 to 0.22.1
  * Bump github.com/fxamacker/cbor/v2 from 2.6.0 to 2.7.0
  * Bump softprops/action-gh-release from 2.0.5 to 2.0.6
  * Set proper JOSE algorithm for Ed25519 keys
  * Bump go.step.sm/crypto from 0.47.0 to 0.47.1
  * Bump go.step.sm/linkedca from 0.21.1 to 0.22.0
  * Bump google.golang.org/protobuf from 1.34.1 to 1.34.2
  * [action] update to common dependabot workflow | use SHAs for
    action versions (#1201)
* Thu Jun 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.26.2:
  * 3aef425 Bump smallstep/certificates to 0.26.2 (#1200)
  * 8268b4f Merge pull request #1195 from
    smallstep/dependabot/go_modules/github.com/Azure/azure-sdk-for-go/sdk/azidentity-1.6.0
  * 0baa3f4 Merge branch 'master' into
    dependabot/go_modules/github.com/Azure/azure-sdk-for-go/sdk/azidentity-1.6.0
  * 3f91698 Changelog update for 0.26.2 (#1198)
  * 4fffd0f Merge pull request #1154 from jdoupe/AuthParams
  * 615f8c8 Fix linter warnings
  * b54fa82 Bump github.com/Azure/azure-sdk-for-go/sdk/azidentity
  * 1b886a4 Merge branch 'master' into AuthParams
  * cc0b543 Merge pull request #1197 from
    smallstep/mariano/certificates
  * 089412e Upgrade certificates to master
  * 7be7142 Merge branch 'master' into AuthParams
  * f0e3653 Merge pull request #1196 from
    smallstep/mariano/linkedca
  * d33d773 Upgrade linkedca dependencies
  * 86aaac3 Merge pull request #1193 from
    smallstep/dependabot/go_modules/golang.org/x/crypto-0.24.0
  * f28438f Bump golang.org/x/crypto from 0.23.0 to 0.24.0
  * e817600 Merge pull request #1191 from
    smallstep/dependabot/go_modules/golang.org/x/term-0.21.0
  * 156bb9f Merge branch 'master' into
    dependabot/go_modules/golang.org/x/term-0.21.0
  * e8f7eb4 Merge pull request #1192 from
    smallstep/dependabot/go_modules/go.step.sm/crypto-0.47.0
  * 613e5f8 Bump go.step.sm/crypto from 0.46.0 to 0.47.0
  * 54974a0 Bump golang.org/x/term from 0.20.0 to 0.21.0
  * dfcab02 Merge pull request #1189 from
    smallstep/dependabot/go_modules/go.step.sm/crypto-0.46.0
  * e621236 Bump go.step.sm/crypto from 0.45.1 to 0.46.0
  * 73cd7f4 Merge pull request #1184 from
    smallstep/dependabot/go_modules/go.step.sm/crypto-0.45.1
  * a7467ed Bump go.step.sm/crypto from 0.45.0 to 0.45.1
  * 7888a37 Merge pull request #1181 from
    smallstep/dependabot/go_modules/go.step.sm/crypto-0.45.0
  * 3fdf6da Bump go.step.sm/crypto from 0.44.8 to 0.45.0
  * 9a01088 Merge pull request #1174 from
    smallstep/carl/template-flags
  * 3156aec Merge pull request #1175 from
    smallstep/carl/template-flags-1
  * af6511a Fix linter errors
  * 9fef15b Add OCSP and CRL support to certificate verify
  * cd22f47 Fix spacing in ssh/certificate with goimports (#1178)
  * 32bdf40 Allow users to define certificate comment in agent
    (#1158)
  * aeee3d0 Add support for setting ssh key types
  * bf70d3e Merge pull request #1177 from
    smallstep/herman/read-certificate-once
  * 42e275a Reduce number of times certificate file is read when
    installing
  * e5ab833 Add CSR common name to SANs if no other SANs are
    defined in CSR (#1172)
  * ae17a8a Add template flags to step ca provisioner add help text
  * d4bd44f Add template flags to step ca provisioner update help
    text
  * 028915b Merge pull request #1170 from
    smallstep/dependabot/go_modules/google.golang.org/protobuf-1.34.1
  * 1e4bb89 Bump google.golang.org/protobuf from 1.33.0 to 1.34.1
  * 48dac3f Merge pull request #1167 from
    smallstep/dependabot/go_modules/golang.org/x/crypto-0.23.0
  * 1f36d23 Allow stdin input of cert for needs-renewal (#1157)
  * d84fb79 Bump golang.org/x/crypto from 0.22.0 to 0.23.0
  * 8e4c5d7 Merge branch 'master' into AuthParams
  * f0aab19 Merge pull request #1166 from
    smallstep/dependabot/go_modules/github.com/urfave/cli-1.22.15
  * b54d419 Merge pull request #1165 from
    smallstep/dependabot/go_modules/github.com/smallstep/certificates-0.26.1
  * 80f0b89 Merge pull request #1164 from
    smallstep/dependabot/github_actions/dependabot/fetch-metadata-2.1.0
  * 54b6212 Bump github.com/urfave/cli from 1.22.14 to 1.22.15
  * 3537984 Bump github.com/smallstep/certificates from 0.26.0 to
    0.26.1
  * cddd7f2 Bump dependabot/fetch-metadata from 2.0.0 to 2.1.0
  * a7b2b3a Merge pull request #1163 from
    smallstep/herman/upgrade-crypto-v0.44.8
  * e356894 Fix go.mod
  * d82d752 Upgrade go.step.sm/crypto to v0.44.8
  * 85e8884 add scope and authparam flags and parameters for OIDC
  * cae069c allow auth scopes from provisioner
  * c216086 add AuthParams to token
* Wed May 29 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package step-cli: A zero trust swiss army knife for working
  with X509, OAuth, JWT, OATH OTP, etc.
